@@ -1,4 +1,4 @@
-#%% begin initialize drupal-6.5-noname-P1
+#%% begin initialize drupal-6.8-noname-P2
 ###################################################################
 export LANG=C
 export PATH=/bin:/usr/bin:/sbin:/usr/sbin
@@ -14,7 +14,7 @@ WWW=$ROOT/home/www
 if [ -f $ROOT/opt/htdocs/drupal6 ]; then
   mv $ROOT/opt/htdocs/drupal6 $ROOT/opt/htdocs/drupal6.bak
 fi
-(cd $ROOT/opt/htdocs; rm -f drupal6; ln -sf drupal-6.5 drupal6 )
+(cd $ROOT/opt/htdocs; rm -f drupal6; ln -sf drupal-6.8 drupal6 )
 
 FQDN=`hostname -f`
 if [ ".$FQDN" = "." ]; then
@@ -53,7 +53,7 @@ if ! fgrep "drupal6/cron.php" $ROOT/var/spool/cron/crontabs/www 1>/dev/null 2>&1
 fi
 
 
-echo "To install japanese package drupal see:"      
-echo "        http://drupal.jp/drupal6/guide/install-step1" 
+#echo "To install japanese package drupal see:"      
+#echo "        http://drupal.jp/drupal6/guide/install-step1" 
 
 #%% end
